
# Slot: subject


connects an association to the subject of the association. For example, in a gene-to-phenotype association, the gene is subject and phenotype is object.

URI: [biolink:exposure_event_to_entity_association_mixin_subject](https://w3id.org/biolink/vocab/exposure_event_to_entity_association_mixin_subject)


## Domain and Range

[ExposureEventToEntityAssociationMixin](ExposureEventToEntityAssociationMixin.md) &#8594;  <sub>1..1</sub> [ExposureEvent](ExposureEvent.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ExposureEventToEntityAssociationMixin](ExposureEventToEntityAssociationMixin.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Local names:** | | annotation subject (ga4gh) |
|  | | node with outgoing relationship (neo4j) |
| **Mappings:** | | rdf:subject |
| **Exact Mappings:** | | owl:annotatedSource |
|  | | OBAN:association_has_subject |

